@@ -337,39 +337,51 @@ extern void Comp_Pair_Gauss_biv2mem(int *cormod, double *data1,double *data2,int
 extern void Comp_Pair_SkewGauss_biv2mem(int *cormod, double *data1,double *data2,int *NN,
     double *par, int *weigthed,double *res,double *mean1,double *mean2,
     double *nuis, int *local,int *GPU);
-extern void Comp_Pair_GaussGCop2mem(int *cormod, double *data1,double *data2,int *NN,
+extern void Comp_Pair_GaussCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_BetaGCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_PoisCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Beta2GCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_TCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_KumaraswamyGCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern  void Comp_Pair_LogisticCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Kumaraswamy2GCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop,int *cond);
+extern void Comp_Pair_BetaCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_GaussCCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_Beta2Cop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_BetaCCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_GammaCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Beta2CCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop,int *cond);
+extern void Comp_Pair_WeibullCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_KumaraswamyCCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop,int *cond);
+extern void Comp_Pair_LogGaussCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Kumaraswamy2CCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *nuis, int *local,int *GPU,int *type_cop,int *cond);
+extern void Comp_Pair_KumaraswamyCop2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_Kumaraswamy2Cop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *par, int *weigthed, double *res,double *mean1,double *mean2,
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
 extern void Comp_Pair_Gauss_misp_T_st2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
- double *nuis, int *local,int *GPU);
+ double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_PoisCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *par, int *weigthed, double *res,double *mean1,double *mean2,
+ double *nuis, int *local,int *GPU,int *type_cop,int *cond);
+extern void Comp_Pair_BinomNNGaussCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *par, int *weigthed, double *res,double *mean1,double *mean2,
+ double *nuis, int *local,int *GPU,int *type_cop,int *cond);
+extern void Comp_Pair_BinomnegGaussCop2mem(int *cormod, double *data1,double *data2,int *NN,
+ double *par, int *weigthed, double *res,double *mean1,double *mean2,
+ double *nuis, int *local,int *GPU,int *type_cop,int *cond);
 
 /*********************** for conditional composite likelihood ***************************************************/
 
@@ -574,36 +586,7 @@ extern void Comp_Cond_LogLogistic_st2mem(int *cormod, double *data1,double *data
 extern void Comp_Cond_Logistic_st2mem(int *cormod, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
                                double *nuis, int *local,int *GPU);
-extern void Comp_Cond_GaussGCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                             double *nuis, int *local,int *GPU);
-extern void Comp_Cond_BetaGCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                            double *nuis, int *local,int *GPU);
-extern void Comp_Cond_Beta2GCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                             double *nuis, int *local,int *GPU);
-extern void Comp_Cond_KumaraswamyGCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                   double *nuis, int *local,int *GPU);
-extern void Comp_Cond_Kumaraswamy2GCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                    double *nuis, int *local,int *GPU);
-extern void Comp_Cond_GaussCCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                             double *nuis, int *local,int *GPU);
-extern void Comp_Cond_BetaCCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                            double *nuis, int *local,int *GPU);
-extern void Comp_Cond_Beta2CCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                             double *nuis, int *local,int *GPU);
-extern void Comp_Cond_KumaraswamyCCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                   double *nuis, int *local,int *GPU);
-extern void Comp_Cond_Kumaraswamy2CCop2mem(int *cormod, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                    double *nuis, int *local,int *GPU);
+
 
 /********************** spatial anisotropic  marginal************************************/
 extern void Comp_Pair_Gauss2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
@@ -723,36 +706,28 @@ extern void Comp_Pair_TWOPIECEGauss2mem_aniso(int *cormod, double *coord1,double
 extern void Comp_Pair_TWOPIECEBIMODAL2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
                                          double *nuis, int *local,int *GPU);
-extern void Comp_Pair_GaussGCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
+extern void Comp_Pair_GaussCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                   double *nuis, int *local,int *GPU);
-extern void Comp_Pair_BetaGCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
+                                   double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_PoisCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                  double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Beta2GCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
+                                   double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_TCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                   double *nuis, int *local,int *GPU);
-extern void Comp_Pair_KumaraswamyGCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
+                                   double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_BetaCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                         double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Kumaraswamy2GCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
+                                  double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_Beta2Cop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                          double *nuis, int *local,int *GPU);
-extern void Comp_Pair_GaussCCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
+                                   double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_KumaraswamyCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                   double *nuis, int *local,int *GPU);
-extern void Comp_Pair_BetaCCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
+                                         double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+extern void Comp_Pair_Kumaraswamy2Cop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
  double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                  double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Beta2CCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                   double *nuis, int *local,int *GPU);
-extern void Comp_Pair_KumaraswamyCCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                         double *nuis, int *local,int *GPU);
-extern void Comp_Pair_Kumaraswamy2CCop2mem_aniso(int *cormod, double *coord1,double *coord2, double *data1,double *data2,int *NN,
- double *par, int *weigthed, double *res,double *mean1,double *mean2,
-                                          double *nuis, int *local,int *GPU);
+                                          double *nuis, int *local,int *GPU,int *type_cop, int *cond);
+
 
 /********************** spatial anisotropic conditional ************************************/
 extern void Comp_Cond_Gauss2mem_aniso(int *cormod, double *coord1, double *coord2,double *data1,double *data2,int *NN,
@@ -1004,17 +979,21 @@ static const R_CMethodDef CEntries[] = {
     {"Comp_Pair_Gauss_misp_PoisZIP_st2mem",         (DL_FUNC) &Comp_Pair_Gauss_misp_PoisZIP_st2mem,         12},
     {"Comp_Pair_LogLogistic_st2mem",         (DL_FUNC) &Comp_Pair_LogLogistic_st2mem,         12},
     {"Comp_Pair_Logistic_st2mem",         (DL_FUNC) &Comp_Pair_Logistic_st2mem,         12},
-    {"Comp_Pair_GaussGCop2mem",         (DL_FUNC) &Comp_Pair_GaussGCop2mem,         12},
-    {"Comp_Pair_BetaGCop2mem",         (DL_FUNC) &Comp_Pair_BetaGCop2mem,         12},
-    {"Comp_Pair_Beta2GCop2mem",         (DL_FUNC) &Comp_Pair_Beta2GCop2mem,         12},
-    {"Comp_Pair_KumaraswamyGCop2mem",         (DL_FUNC) &Comp_Pair_KumaraswamyGCop2mem,         12},
-    {"Comp_Pair_Kumaraswamy2GCop2mem",         (DL_FUNC) &Comp_Pair_Kumaraswamy2GCop2mem,         12},//90
-    {"Comp_Pair_GaussCCop2mem",         (DL_FUNC) &Comp_Pair_GaussCCop2mem,         12},
-    {"Comp_Pair_BetaCCop2mem",         (DL_FUNC) &Comp_Pair_BetaCCop2mem,         12},
-    {"Comp_Pair_Beta2CCop2mem",         (DL_FUNC) &Comp_Pair_Beta2CCop2mem,         12},//93
-  
+  /*********************** for copula ***************************************************/
+    {"Comp_Pair_GaussCop2mem",         (DL_FUNC) &Comp_Pair_GaussCop2mem,         14},
+    {"Comp_Pair_LogGaussCop2mem",         (DL_FUNC) &Comp_Pair_LogGaussCop2mem,         14},
+    {"Comp_Pair_LogisticCop2mem",         (DL_FUNC) &Comp_Pair_LogisticCop2mem,         14},
+    {"Comp_Pair_PoisCop2mem",         (DL_FUNC) &Comp_Pair_PoisCop2mem,         14},
+    {"Comp_Pair_WeibullCop2mem",         (DL_FUNC) &Comp_Pair_WeibullCop2mem,         14},
+    {"Comp_Pair_GammaCop2mem",         (DL_FUNC) &Comp_Pair_GammaCop2mem,         14},
+    {"Comp_Pair_BinomNNGaussCop2mem",         (DL_FUNC) &Comp_Pair_BinomNNGaussCop2mem,         14}, 
+    {"Comp_Pair_BinomnegGaussCop2mem",         (DL_FUNC) &Comp_Pair_BinomnegGaussCop2mem,         14},    
+    {"Comp_Pair_TCop2mem",         (DL_FUNC) &Comp_Pair_TCop2mem,         14},
+    {"Comp_Pair_BetaCop2mem",         (DL_FUNC) &Comp_Pair_BetaCop2mem,         14},
+    {"Comp_Pair_Beta2Cop2mem",         (DL_FUNC) &Comp_Pair_Beta2Cop2mem,         14},
+    {"Comp_Pair_KumaraswamyCop2mem",         (DL_FUNC) &Comp_Pair_KumaraswamyCop2mem,         14},
+    {"Comp_Pair_Kumaraswamy2Cop2mem",         (DL_FUNC) &Comp_Pair_Kumaraswamy2Cop2mem,         14},//90
     /*********************** for conditional composite likelihood ***************************************************/
-    
     {"Comp_Cond_Gauss2mem",         (DL_FUNC) &Comp_Cond_Gauss2mem,         12},
     {"Comp_Cond_Tukeyh2mem",         (DL_FUNC) &Comp_Cond_Tukeyh2mem,         12},
     {"Comp_Cond_Tukeyhh2mem",         (DL_FUNC) &Comp_Cond_Tukeyhh2mem,         12},
@@ -1079,17 +1058,9 @@ static const R_CMethodDef CEntries[] = {
     {"Comp_Cond_Gauss_misp_PoisZIP_st2mem",         (DL_FUNC) &Comp_Cond_Gauss_misp_PoisZIP_st2mem,         12},
     {"Comp_Cond_LogLogistic_st2mem",         (DL_FUNC) &Comp_Cond_LogLogistic_st2mem,         12},
     {"Comp_Cond_Logistic_st2mem",         (DL_FUNC) &Comp_Cond_Logistic_st2mem,         12},
-    {"Comp_Cond_GaussGCop2mem",         (DL_FUNC) &Comp_Cond_GaussGCop2mem,         12},
-    {"Comp_Cond_BetaGCop2mem",         (DL_FUNC) &Comp_Cond_BetaGCop2mem,         12},
-    {"Comp_Cond_Beta2GCop2mem",         (DL_FUNC) &Comp_Cond_Beta2GCop2mem,         12},
-    {"Comp_Cond_KumaraswamyGCop2mem",         (DL_FUNC) &Comp_Cond_KumaraswamyGCop2mem,         12},
-    {"Comp_Cond_Kumaraswamy2GCop2mem",         (DL_FUNC) &Comp_Cond_Kumaraswamy2GCop2mem,         12},//90
-    {"Comp_Cond_GaussCCop2mem",         (DL_FUNC) &Comp_Cond_GaussCCop2mem,         12},
-    {"Comp_Cond_BetaCCop2mem",         (DL_FUNC) &Comp_Cond_BetaCCop2mem,         12},
-    {"Comp_Cond_Beta2CCop2mem",         (DL_FUNC) &Comp_Cond_Beta2CCop2mem,         12},//93
-    
     /********************** spatial anisotropic +************************************/
     {"Comp_Pair_Gauss2mem_aniso",         (DL_FUNC) &Comp_Pair_Gauss2mem_aniso,         14},
+    {"Comp_Pair_Pois2mem_aniso",         (DL_FUNC) &Comp_Pair_Gauss2mem_aniso,         14},
     {"Comp_Diff_Gauss2mem_aniso",         (DL_FUNC) &Comp_Diff_Gauss2mem_aniso,         14},
     {"Comp_Pair_WrapGauss2mem_aniso",         (DL_FUNC) &Comp_Pair_WrapGauss2mem_aniso,         14},
     {"Comp_Pair_SinhGauss2mem_aniso",         (DL_FUNC) &Comp_Pair_SinhGauss2mem_aniso,         14},
@@ -1111,7 +1082,6 @@ static const R_CMethodDef CEntries[] = {
     {"Comp_Pair_BinomNNLogi2mem_aniso",         (DL_FUNC) &Comp_Pair_BinomNNLogi2mem_aniso,         14},
     {"Comp_Pair_LogLogistic2mem_aniso",         (DL_FUNC) &Comp_Pair_LogLogistic2mem_aniso,         14},
     {"Comp_Pair_Logistic2mem_aniso",         (DL_FUNC) &Comp_Pair_Logistic2mem_aniso,         14},
-    {"Comp_Pair_Pois2mem_aniso",         (DL_FUNC) &Comp_Pair_Pois2mem_aniso,         14},
     {"Comp_Pair_PoisGamma2mem_aniso",         (DL_FUNC) &Comp_Pair_PoisGamma2mem_aniso,         14},
     {"Comp_Pair_Gauss_misp_PoisGamma2mem_aniso",         (DL_FUNC) &Comp_Pair_Gauss_misp_PoisGamma2mem_aniso,         14},
     {"Comp_Pair_PoisZIP2mem_aniso",         (DL_FUNC) &Comp_Pair_PoisZIP2mem_aniso,         14},
@@ -1127,15 +1097,14 @@ static const R_CMethodDef CEntries[] = {
     {"Comp_Pair_TWOPIECET2mem_aniso",         (DL_FUNC) &Comp_Pair_TWOPIECET2mem_aniso,         14},
     {"Comp_Pair_TWOPIECEGauss2mem_aniso",         (DL_FUNC) &Comp_Pair_TWOPIECEGauss2mem_aniso,         14},
     {"Comp_Pair_TWOPIECEBIMODAL2mem_aniso",         (DL_FUNC) &Comp_Pair_TWOPIECEBIMODAL2mem_aniso,         14},
-    {"Comp_Pair_GaussGCop2mem_aniso",         (DL_FUNC) &Comp_Pair_GaussGCop2mem_aniso,         14},
-    {"Comp_Pair_BetaGCop2mem_aniso",         (DL_FUNC) &Comp_Pair_BetaGCop2mem_aniso,         14},
-    {"Comp_Pair_Beta2GCop2mem_aniso",         (DL_FUNC) &Comp_Pair_Beta2GCop2mem_aniso,         14},
-    {"Comp_Pair_KumaraswamyGCop2mem_aniso",         (DL_FUNC) &Comp_Pair_KumaraswamyGCop2mem_aniso,         14},
-    {"Comp_Pair_Kumaraswamy2GCop2mem_aniso",         (DL_FUNC) &Comp_Pair_Kumaraswamy2GCop2mem_aniso,         14},
-    {"Comp_Pair_GaussCCop2mem_aniso",         (DL_FUNC) &Comp_Pair_GaussCCop2mem_aniso,         14},
-    {"Comp_Pair_Beta2CCop2mem_aniso",         (DL_FUNC) &Comp_Pair_Beta2CCop2mem_aniso,         14},
-    {"Comp_Pair_KumaraswamyCCop2mem_aniso",         (DL_FUNC) &Comp_Pair_KumaraswamyCCop2mem_aniso,         14},
-    {"Comp_Pair_Kumaraswamy2CCop2mem_aniso",         (DL_FUNC) &Comp_Pair_Kumaraswamy2CCop2mem_aniso,         14},
+
+    {"Comp_Pair_GaussCop2mem_aniso",         (DL_FUNC) &Comp_Pair_GaussCop2mem_aniso,         16},
+    {"Comp_Pair_TCop2mem_aniso",         (DL_FUNC) &Comp_Pair_TCop2mem_aniso,         16},
+    {"Comp_Pair_BetaCop2mem_aniso",         (DL_FUNC) &Comp_Pair_BetaCop2mem_aniso,         16},
+    {"Comp_Pair_Beta2Cop2mem_aniso",         (DL_FUNC) &Comp_Pair_Beta2Cop2mem_aniso,         16},
+    {"Comp_Pair_KumaraswamyCop2mem_aniso",         (DL_FUNC) &Comp_Pair_KumaraswamyCop2mem_aniso,         16},
+    {"Comp_Pair_Kumaraswamy2Cop2mem_aniso",         (DL_FUNC) &Comp_Pair_Kumaraswamy2Cop2mem_aniso,         16},
+
     {"Comp_Cond_Gauss2mem_aniso",         (DL_FUNC) &Comp_Cond_Gauss2mem_aniso,         14},
     {"Comp_Cond_Tukeyhh2mem_aniso",         (DL_FUNC) &Comp_Cond_Tukeyhh2mem_aniso,         14},
     {"Comp_Cond_SkewGauss2mem_aniso",         (DL_FUNC) &Comp_Cond_SkewGauss2mem_aniso,         14},
